@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: fdo-notify
 version: 0.3.1
-id: fdo-notify-0.3.1-6b389ddcfddf351738e12e738b7f4308
-key: fdono_IUrd5TqiQNJ0aRP3SlRszS
+id: fdo-notify-0.3.1-3f25a6295fb292c120ec9689eb2af950
+key: fdono_FFxFt4tjeMl9mQ1zhMN0A2
 license: BSD3
 maintainer: max.rabkin@gmail.com
 homepage: http://bitbucket.org/taejo/fdo-notify/
@@ -21,11 +21,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/fdo-notify-0.3.1
 library-dirs: /usr/lib/ghc-7.10.3/site-local/fdo-notify-0.3.1
 data-dir: /usr/share/arm-linux-ghc-7.10.3/fdo-notify-0.3.1
-hs-libraries: HSfdo-notify-0.3.1-IUrd5TqiQNJ0aRP3SlRszS
+hs-libraries: HSfdo-notify-0.3.1-FFxFt4tjeMl9mQ1zhMN0A2
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    dbus-0.10.12-f6f03c921bc449e06e2b31ac6de64e68
+    dbus-0.10.12-8a56715ad4c74b16585ed43d4af51957
 haddock-interfaces: /usr/share/doc/haskell-fdo-notify/html/fdo-notify.haddock
 haddock-html: /usr/share/doc/haskell-fdo-notify/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
